﻿//========================================================================================
// "Рамки с фигурными углами"
//    (CornerBorder.js)
//
// Версия 1.3
//
//    Скрипт предназначен для заключения абзацев текста указанного стиля в рамки
// с фигурными углами (Corner Effects...)
//
// ************************* Проблемы и ограничения **************************************
//    Не могу сделать отступы текста внутри получающихся фреймов
//    Искомый параграф не должен быть последним, т.е. после него отбить пустой параграф
//
// 1.1 Исправления отступов
//
// 1.2 Исправлена проблема наползания текста
//
// 1.3 Добавлен выбор связки фреймов: если выбран один текстовый фрейм - будет обработан 
//     только этот фрейм, если текстовый курсор стоит в тексте - будет отработана связка 
//     фреймов.
//
// Автор: Андрей Рыжков (ragman)
//
// Дата: 04.04.2005 г.
//
//=========================================================================================
var scriptName = "Рамки с фигурными углами";
var scriptVer = " 1.3";

// Умолчания
var myParagraphStyle = "рамка";
var myCornerEffect = "rounded";
var myCornerRadius = "5";
var myStyleLine = "Solid";
var myColorLine = "Black";
var myStrokeWeight = 1;
var myInsetSpacing = "1";

function cornerRound (myTextFrame, myPage) {

	// Для каждого абзаца текста
	for (myCounter = 0; myCounter < myTextFrame.paragraphs.length; myCounter++) {
		myPara = myTextFrame.paragraphs[myCounter];
		if (myPara.appliedParagraphStyle.name == myParagraphStyle){
			// Вырезать текст без концевого символа
			var myText = myPara.characters.itemByRange(0, (myPara.characters.length - 2));
			myText.select(1919250519);
			app.cut();
			// Установить красную строку в 0
			myPara.firstLineIndent = 0;
			myPara.leftIndent = 0;
			myPara.leading = -1;
			//Определяем ширину колонки
			var columnWidth = myTextFrame.textFramePreferences.textColumnFixedWidth;
			// Вставить текстовый фрейм и применить угловые эффекты
			var myNewTextFrame = myPage.textFrames.add();
			with (myNewTextFrame) {
				strokeWeight = myStrokeWeight;
				strokeType = myStyleLine;
				strokeColor = myColorLine;
				//geometricBounds [y1, x1, y2, x2]
				geometricBounds = [0, 0, 100, columnWidth];
				textFramePreferences.insetSpacing = new Array(myInsetSpacing, myInsetSpacing, myInsetSpacing, myInsetSpacing);
				cornerEffect = myCornerEffect;
				cornerRadius = myCornerRadius;
				insertionPoints[0].select(1919250519);
				app.paste();
				fit(given = 1718906723);
				geometricBounds = [geometricBounds[0], geometricBounds[1], geometricBounds[2], columnWidth];
			}
			
			// Рамку вставить в исходный текст
			myNewTextFrame.select(1919250519);
			app.cut();
			myPara.insertionPoints[0].select(1919250519);
			app.paste();
		}
	}
}


with (app) {
	//Проверяем, что у нас выделено
	if ((selection.length == 1)&&((selection[0].constructor.name == "TextFrame") || selection[0].constructor.name == "InsertionPoint")) {
	} else {
		alert("Необходимо вытелить один текстовый фрейм");
		exit();
	}
	
	var myDoc = activeDocument;
	
	//Получаем список стилей абзаца	
	var myStyleNames = new Array();
	var mySelectIndexStyle = 0;
	for (myCounter = 0; myCounter < myDoc.paragraphStyles.length; myCounter++) {
		myStyleNames[myCounter] = myDoc.paragraphStyles[myCounter].name;
		if (myStyleNames[myCounter] == myParagraphStyle) {
			mySelectIndexStyle = myCounter;
		}
	}
	
	// Создаем список оформления угла
	var myCornerEffectList = new Array ("none", "rounded", "inverse rounded", "inset", "bevel", "fancy");
	var myCornerEffectValue = new Array (1852796517, 1667592804, 1667591798, 1667591795, 1667588726, 1667589742);
	var mySelectIndexCorner = 0;
	for (myCounter = 0; myCounter < myCornerEffectList.length; myCounter++) {
		if (myCornerEffectList[myCounter] == myCornerEffect) {
			mySelectIndexCorner = myCounter;
		}
	}

	//Получаем список стилей линий
	var myStyleLineName = new Array();
	var mySelectIndexStyleLine = 0;
	for (myCounter = 0; myCounter < myDoc.strokeStyles.length; myCounter++) {
		myStyleLineName[myCounter] = myDoc.strokeStyles[myCounter].name;
		if (myStyleLineName[myCounter] == myStyleLine) {
			mySelectIndexStyleLine = myCounter;
		}
	}
	
	// Получаем список цветов в публикации
	var myColorSwatchesName = new Array();
	var mySelectIndexColor = 0;
	for (myCounter = 0; myCounter < myDoc.swatches.length; myCounter++) {
		myColorSwatchesName[myCounter] = myDoc.swatches.item(myCounter).name;
		if (myColorSwatchesName[myCounter] == myColorLine) {
			mySelectIndexColor = myCounter;
		}
	}


// Морда лица
	// Создаем диалог
	var myDialog = dialogs.add({name:scriptName + scriptVer});
	// Подготовка
	with (myDialog.dialogColumns.add()) {
		with (dialogRows.add().borderPanels.add()) {
			with (dialogColumns.add()) {
				dialogRows.add().staticTexts.add({staticLabel:"Стиль абзаца"});
				dialogRows.add().staticTexts.add({staticLabel:"Оформление углов"});
				dialogRows.add().staticTexts.add({staticLabel:"Радиус углов"});
				dialogRows.add().staticTexts.add({staticLabel:"Внутренние отступы"});
				dialogRows.add().staticTexts.add({staticLabel:"Стиль линии"});
				dialogRows.add().staticTexts.add({staticLabel:"Толщина линии"});
				dialogRows.add().staticTexts.add({staticLabel:"Цвет линии"});
			}
			with (dialogColumns.add()) {
				var mySelectStyle = dialogRows.add().dropdowns.add({stringList:myStyleNames, selectedIndex:mySelectIndexStyle});
				var mySelectCorner = dialogRows.add().dropdowns.add({stringList:myCornerEffectList, selectedIndex:mySelectIndexCorner});
				var mySelectCornerRadius = dialogRows.add().measurementEditboxes.add({editContents:myCornerRadius, editUnits:2053991795}); //
				var mySelectInsetSpacing = dialogRows.add().measurementEditboxes.add({editContents:myInsetSpacing, editUnits:2053991795});
				var mySelectStyleLine = dialogRows.add().dropdowns.add({stringList:myStyleLineName, selectedIndex:mySelectIndexStyleLine});
				var mySelectStrokeWeight = dialogRows.add().measurementEditboxes.add({editValue:myStrokeWeight, editUnits:2054188905});
				var mySelectColor = dialogRows.add().dropdowns.add({stringList:myColorSwatchesName, selectedIndex:mySelectIndexColor});
			}
		}
		with (dialogRows.add()) {
			dialogColumns.add().staticTexts.add({staticLabel:"Андрей Рыжков     special946@gmail.com"});
		}
	}
	// Показываем
	var myResult = myDialog.show();
	if (!myResult) {
		myDialog.destroy();
		exit();
	}
	
	myParagraphStyle = myDoc.paragraphStyles[mySelectStyle.selectedIndex].name;
	myCornerEffect = myCornerEffectValue[mySelectCorner.selectedIndex];
	myCornerRadius = Number (mySelectCornerRadius.editContents);
	myStyleLine = myStyleLineName[mySelectStyleLine.selectedIndex];
	myStrokeWeight = mySelectStrokeWeight.editValue;
	myColorLine = myDoc.swatches.item(myColorSwatchesName[mySelectColor.selectedIndex]);
	myInsetSpacing = mySelectInsetSpacing.editContents;

	//Определяем текст
	switch (selection[0].constructor.name) {
		case "InsertionPoint":
			var myStory = selection[0].parentStory;
			break;
		case "TextFrame":
			var myStory = false;
	}
//	var myStory = selection[0].parentStory;
	if (myStory) {
		for (myTextFramesCount = 0; myTextFramesCount < myStory.textFrames.length; myTextFramesCount++) {
			var myTextFrame = myStory.textFrames[myTextFramesCount];
			var pageNum = myTextFrame.parent.id;
			var myPage = activeDocument.pages.itemByID(pageNum);
			cornerRound (myTextFrame, myPage)
		}
	}
	else {
		myTextFrame = selection[0];
		var pageNum = myTextFrame.parent.id;
		var myPage = activeDocument.pages.itemByID(pageNum);
		cornerRound (myTextFrame, myPage)
	}
}
